Coverage report

File | function | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | --- | ---
src\attipy\__init__.py | (no function) | 2 | 0 | 0 | 0 | 0 | 100%
src\attipy\_attitude.py | _asarray_check_unit_quaternion | 7 | 2 | 0 | 4 | 2 | 64%
src\attipy\_attitude.py | _asarray_check_matrix_so3 | 9 | 3 | 0 | 6 | 3 | 60%
src\attipy\_attitude.py | Attitude.__init__ | 1 | 0 | 0 | 0 | 0 | 100%
src\attipy\_attitude.py | Attitude.__repr__ | 2 | 0 | 0 | 0 | 0 | 100%
src\attipy\_attitude.py | Attitude.from_quaternion | 1 | 0 | 0 | 0 | 0 | 100%
src\attipy\_attitude.py | Attitude.as_quaternion | 1 | 1 | 0 | 0 | 0 | 0%
src\attipy\_attitude.py | Attitude.from_matrix | 3 | 0 | 0 | 0 | 0 | 100%
src\attipy\_attitude.py | Attitude.as_matrix | 1 | 0 | 0 | 0 | 0 | 100%
src\attipy\_attitude.py | Attitude.from_euler | 5 | 0 | 0 | 2 | 0 | 100%
src\attipy\_attitude.py | Attitude.as_euler | 4 | 0 | 0 | 2 | 0 | 100%
src\attipy\_attitude.py | (no function) | 18 | 0 | 0 | 0 | 0 | 100%
src\attipy\_transforms.py | _quaternion_from_matrix | 29 | 29 | 0 | 6 | 0 | 0%
src\attipy\_transforms.py | _rot_matrix_from_quaternion | 24 | 24 | 0 | 0 | 0 | 0%
src\attipy\_transforms.py | _euler_zyx_from_quaternion | 5 | 5 | 0 | 0 | 0 | 0%
src\attipy\_transforms.py | _rot_matrix_from_euler_zyx | 18 | 18 | 0 | 0 | 0 | 0%
src\attipy\_transforms.py | _quaternion_from_euler_zyx | 12 | 12 | 0 | 0 | 0 | 0%
src\attipy\_transforms.py | (no function) | 14 | 0 | 0 | 0 | 0 | 100%
src\attipy\_vectorops.py | _normalize | 1 | 1 | 0 | 0 | 0 | 0%
src\attipy\_vectorops.py | _quaternion_product | 3 | 3 | 0 | 0 | 0 | 0%
src\attipy\_vectorops.py | (no function) | 7 | 0 | 0 | 0 | 0 | 100%
Total |  | 167 | 98 | 0 | 20 | 5 | 42%

No items found using the specified filter.